summaryrefslogtreecommitdiff
path: root/src/mongo/db/query/stage_types.h
diff options
context:
space:
mode:
authorDavid Storch <david.storch@10gen.com>2015-02-12 13:54:11 -0500
committerDavid Storch <david.storch@10gen.com>2015-02-20 10:26:12 -0500
commitbe2f8584a96d44a0c82b40b472dbc92ac10508f9 (patch)
treef91a691cfbb60617ee092ad5c9cddbb4ac927648 /src/mongo/db/query/stage_types.h
parentae18bbec33db1c4bf57d328505474eb7bba517df (diff)
downloadmongo-be2f8584a96d44a0c82b40b472dbc92ac10508f9.tar.gz
SERVER-4494 add index version to explain output
Diffstat (limited to 'src/mongo/db/query/stage_types.h')
-rw-r--r--src/mongo/db/query/stage_types.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mongo/db/query/stage_types.h b/src/mongo/db/query/stage_types.h
index 83574b4292d..273da805283 100644
--- a/src/mongo/db/query/stage_types.h
+++ b/src/mongo/db/query/stage_types.h
@@ -51,8 +51,8 @@ namespace mongo {
STAGE_DELETE,
// If we're running a distinct, we only care about one value for each key. The distinct
- // stage is an ixscan with some key-skipping behvaior that only distinct uses.
- STAGE_DISTINCT,
+ // scan stage is an ixscan with some key-skipping behvaior that only distinct uses.
+ STAGE_DISTINCT_SCAN,
// Dummy stage used for receiving notifications of deletions during chunk migration.
STAGE_NOTIFY_DELETE,